/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * A SAS definition bundle consists of key vault SAS definition details plus
 * its attributes.
 *
 */
class SasDefinitionBundle {
  /**
   * Create a SasDefinitionBundle.
   * @member {string} [id] The SAS definition id.
   * @member {string} [secretId] Storage account SAS definition secret id.
   * @member {string} [templateUri] The SAS definition token template signed
   * with an arbitrary key.  Tokens created according to the SAS definition
   * will have the same properties as the template.
   * @member {string} [sasType] The type of SAS token the SAS definition will
   * create. Possible values include: 'account', 'service'
   * @member {string} [validityPeriod] The validity period of SAS tokens
   * created according to the SAS definition.
   * @member {object} [attributes] The SAS definition attributes.
   * @member {boolean} [attributes.enabled] the enabled state of the object.
   * @member {date} [attributes.created] Creation time in UTC.
   * @member {date} [attributes.updated] Last updated time in UTC.
   * @member {string} [attributes.recoveryLevel] Reflects the deletion recovery
   * level currently in effect for SAS definitions in the current vault. If it
   * contains 'Purgeable' the SAS definition can be permanently deleted by a
   * privileged user; otherwise, only the system can purge the SAS definition,
   * at the end of the retention interval. Possible values include:
   * 'Purgeable', 'Recoverable+Purgeable', 'Recoverable',
   * 'Recoverable+ProtectedSubscription'
   * @member {object} [tags] Application specific metadata in the form of
   * key-value pairs
   */
  constructor() {
  }

  /**
   * Defines the metadata of SasDefinitionBundle
   *
   * @returns {object} metadata of SasDefinitionBundle
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'SasDefinitionBundle',
      type: {
        name: 'Composite',
        className: 'SasDefinitionBundle',
        modelProperties: {
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          secretId: {
            required: false,
            readOnly: true,
            serializedName: 'sid',
            type: {
              name: 'String'
            }
          },
          templateUri: {
            required: false,
            readOnly: true,
            serializedName: 'templateUri',
            type: {
              name: 'String'
            }
          },
          sasType: {
            required: false,
            readOnly: true,
            serializedName: 'sasType',
            type: {
              name: 'String'
            }
          },
          validityPeriod: {
            required: false,
            readOnly: true,
            serializedName: 'validityPeriod',
            type: {
              name: 'String'
            }
          },
          attributes: {
            required: false,
            readOnly: true,
            serializedName: 'attributes',
            type: {
              name: 'Composite',
              className: 'SasDefinitionAttributes'
            }
          },
          tags: {
            required: false,
            readOnly: true,
            serializedName: 'tags',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          }
        }
      }
    };
  }
}

module.exports = SasDefinitionBundle;
