/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

'use strict';

const models = require('./index');

/**
 * A Storage account bundle consists of key vault storage account details plus
 * its attributes.
 *
 */
class StorageBundle {
  /**
   * Create a StorageBundle.
   * @member {string} [id] The storage account id.
   * @member {string} [resourceId] The storage account resource id.
   * @member {string} [activeKeyName] The current active storage account key
   * name.
   * @member {boolean} [autoRegenerateKey] whether keyvault should manage the
   * storage account for the user.
   * @member {string} [regenerationPeriod] The key regeneration time duration
   * specified in ISO-8601 format.
   * @member {object} [attributes] The storage account attributes.
   * @member {boolean} [attributes.enabled] the enabled state of the object.
   * @member {date} [attributes.created] Creation time in UTC.
   * @member {date} [attributes.updated] Last updated time in UTC.
   * @member {string} [attributes.recoveryLevel] Reflects the deletion recovery
   * level currently in effect for storage accounts in the current vault. If it
   * contains 'Purgeable' the storage account can be permanently deleted by a
   * privileged user; otherwise, only the system can purge the storage account,
   * at the end of the retention interval. Possible values include:
   * 'Purgeable', 'Recoverable+Purgeable', 'Recoverable',
   * 'Recoverable+ProtectedSubscription'
   * @member {object} [tags] Application specific metadata in the form of
   * key-value pairs
   */
  constructor() {
  }

  /**
   * Defines the metadata of StorageBundle
   *
   * @returns {object} metadata of StorageBundle
   *
   */
  mapper() {
    return {
      required: false,
      serializedName: 'StorageBundle',
      type: {
        name: 'Composite',
        className: 'StorageBundle',
        modelProperties: {
          id: {
            required: false,
            readOnly: true,
            serializedName: 'id',
            type: {
              name: 'String'
            }
          },
          resourceId: {
            required: false,
            readOnly: true,
            serializedName: 'resourceId',
            type: {
              name: 'String'
            }
          },
          activeKeyName: {
            required: false,
            readOnly: true,
            serializedName: 'activeKeyName',
            type: {
              name: 'String'
            }
          },
          autoRegenerateKey: {
            required: false,
            readOnly: true,
            serializedName: 'autoRegenerateKey',
            type: {
              name: 'Boolean'
            }
          },
          regenerationPeriod: {
            required: false,
            readOnly: true,
            serializedName: 'regenerationPeriod',
            type: {
              name: 'String'
            }
          },
          attributes: {
            required: false,
            readOnly: true,
            serializedName: 'attributes',
            type: {
              name: 'Composite',
              className: 'StorageAccountAttributes'
            }
          },
          tags: {
            required: false,
            readOnly: true,
            serializedName: 'tags',
            type: {
              name: 'Dictionary',
              value: {
                  required: false,
                  serializedName: 'StringElementType',
                  type: {
                    name: 'String'
                  }
              }
            }
          }
        }
      }
    };
  }
}

module.exports = StorageBundle;
